fn build_comment_map(
comments: &[Comment],
_source: &str,
) -> HashMap<usize, NatspecDocIR>Expand description
Build a map from source positions to their preceding Natspec comments.
fn build_comment_map(
comments: &[Comment],
_source: &str,
) -> HashMap<usize, NatspecDocIR>Build a map from source positions to their preceding Natspec comments.