fn find_preceding_doc(
loc: &Loc,
comment_map: &HashMap<usize, NatspecDocIR>,
) -> NatspecDocIRExpand description
Find the doc comment that precedes a given source location
fn find_preceding_doc(
loc: &Loc,
comment_map: &HashMap<usize, NatspecDocIR>,
) -> NatspecDocIRFind the doc comment that precedes a given source location