pub enum BuiltinCall {
Show 25 variants
RuntimeNotify,
RuntimeCheckWitness,
AbiEncode,
AbiEncodePacked,
AbiEncodeCall,
AbiEncodeWithSignature,
AbiDecode,
Keccak256,
Ecrecover,
StorageFind,
StoragePut,
StorageGet,
StorageDelete,
ContractCall,
ContractCallWithFlags,
NotifySerialized,
VerifySignature,
DeployContract,
GetContract,
GetContractScript,
GetNeoAccountState,
NativeCall {
contract: NativeContract,
method: String,
},
Syscall(String),
TypeOf,
BytesConcat,
}Variants
RuntimeNotify
RuntimeCheckWitness
AbiEncode
AbiEncodePacked
AbiEncodeCall
AbiEncodeWithSignature
AbiDecode
Keccak256
Ecrecover
StorageFind
StoragePut
StorageGet
StorageDelete
ContractCall
ContractCallWithFlags
NotifySerialized
VerifySignature
DeployContract
Convenience wrapper for ContractManagement.deploy that returns only the deployed
contract hash (UInt160) rather than the full ContractState.
GetContract
Convenience wrapper for ContractManagement.getContract that reshapes the returned
ContractState into a devpack-friendly struct:
[hash, nef, serialize(manifest), updateCounter].
GetContractScript
Convenience wrapper for fetching the NEF file from a contract state.
This is exposed as Syscalls.getContractScript in the devpack.
GetNeoAccountState
Convenience wrapper for NeoToken.getAccountState that:
- Returns a default struct when the native contract returns
null. - Normalizes the
voteTofield to an empty byte string when it isnull.
NativeCall
Syscall(String)
TypeOf
BytesConcat
bytes.concat(a, b, ...) / string.concat(a, b, ...) — chains NeoVM CAT opcodes.