Instruction

Enum Instruction 

pub enum Instruction {
Show 44 variants Drop(ValueType), Dup, Swap, LoadParameter(usize), PushLiteral(LiteralValue), Return, ReturnVoid, ReturnDefault(ValueType), BinaryOp(BinaryOperator), LoadState(usize), StoreState(usize), LoadStorageDynamic, LoadLocal(usize), StoreLocal(usize), LoadMappingElement { state_index: usize, key_types: Vec<ValueType>, }, StoreMappingElement { state_index: usize, key_types: Vec<ValueType>, }, LoadStructField { state_index: usize, key_types: Vec<ValueType>, field_keys: Vec<[u8; 32]>, field_type: ValueType, }, StoreStructField { state_index: usize, key_types: Vec<ValueType>, field_keys: Vec<[u8; 32]>, field_type: ValueType, }, LoadStructArrayElement { state_index: usize, key_types: Vec<ValueType>, field_keys: Vec<[u8; 32]>, element_type: ValueType, }, StoreStructArrayElement { state_index: usize, key_types: Vec<ValueType>, field_keys: Vec<[u8; 32]>, element_type: ValueType, }, LoadRuntimeValue(RuntimeValue), GetSize, CallFunction { name: String, arg_count: usize, }, CallBuiltin { builtin: BuiltinCall, arg_count: usize, }, EmitEvent { event_index: usize, arg_count: usize, }, EmitEventByName { name: String, arg_count: usize, }, Convert { target: ConvertTarget, }, IsType { target: ConvertTarget, }, NewBuffer, NewArray { element_type: ValueType, }, ArrayGet, ArraySet, MemCpy, ReverseItems, BitwiseNot, LogicalNot, Try { catch_target: usize, }, EndTry { target: usize, }, Jump { target: usize, }, JumpIf { target: usize, }, Label(usize), Throw, AbortMsg, Abort,
}

Variants



Drop(ValueType)



Dup

NeoVM DUP - duplicate the top stack item



Swap

NeoVM SWAP - swap the top two stack items



LoadParameter(usize)



PushLiteral(LiteralValue)



Return



ReturnVoid



ReturnDefault(ValueType)



BinaryOp(BinaryOperator)



LoadState(usize)



StoreState(usize)



LoadStorageDynamic



LoadLocal(usize)



StoreLocal(usize)



LoadMappingElement

Fields

state_index: usize
key_types: Vec<ValueType>


StoreMappingElement

Fields

state_index: usize
key_types: Vec<ValueType>


LoadStructField

Fields

state_index: usize
key_types: Vec<ValueType>
field_keys: Vec<[u8; 32]>
field_type: ValueType


StoreStructField

Fields

state_index: usize
key_types: Vec<ValueType>
field_keys: Vec<[u8; 32]>
field_type: ValueType


LoadStructArrayElement

Fields

state_index: usize
key_types: Vec<ValueType>
field_keys: Vec<[u8; 32]>
element_type: ValueType


StoreStructArrayElement

Fields

state_index: usize
key_types: Vec<ValueType>
field_keys: Vec<[u8; 32]>
element_type: ValueType


LoadRuntimeValue(RuntimeValue)



GetSize



CallFunction

Fields

name: String
arg_count: usize


CallBuiltin

Fields

builtin: BuiltinCall
arg_count: usize


EmitEvent

Fields

event_index: usize
arg_count: usize


EmitEventByName

Fields

name: String
arg_count: usize


Convert

NeoVM CONVERT opcode. Converts the top stack item to a different StackItemType.

Fields



IsType

NeoVM ISTYPE opcode. Checks whether the top stack item matches a StackItemType and pushes a boolean.

Fields



NewBuffer

Allocate a new mutable buffer (NeoVM NEWBUFFER) whose length is taken from the stack. Used to implement Solidity new bytes(n) / new string(n) allocations.



NewArray

Fields

element_type: ValueType


ArrayGet



ArraySet



MemCpy

NeoVM MEMCPY opcode: copy a slice of bytes into a buffer. Stack order (bottom -> top): [dst, dst_offset, src, src_offset, count]



ReverseItems

NeoVM REVERSEITEMS opcode: reverse an Array/Buffer in place. Note: consumes one reference and does not push it back.



BitwiseNot



LogicalNot

NeoVM NOT (0xAA) — logical boolean negation. Pops one value, pushes !value.is_truthy(). Correctly handles null (returns true), unlike PUSHF + EQUAL.



Try

Fields

catch_target: usize


EndTry

Fields

target: usize


Jump

Fields

target: usize


JumpIf

Fields

target: usize


Label(usize)



Throw

NeoVM THROW - raises a catchable exception using the value on the stack.



AbortMsg



Abort